/*
 * ********************************************************************************************************************
 *
 *                     :*$@@%$*:                         ;:                ;;    ;;
 *                   :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                  :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                  =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                  =@*                                  %!              @ $= % %@=   =%@!      %=
 *             *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *           %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *         ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *         $@*   ;@@@%=!:                *@*
 *         =@$    ;;;!=%@@@@=!           =@!
 *          %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *           ;%@@$=$@@%*       *@@@$=%@@%;
 *              ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

package com.persagy.server.controllers.objects

import com.persagy.server.datacenter.models.entities.objects.Equipment
import com.persagy.server.datacenter.models.entities.objects.GeneralSystem
import com.persagy.server.datacenter.models.entities.objects.Shaft
import com.persagy.server.datacenter.models.entities.objects.ZoneSpace
import com.persagy.server.datacenter.models.entities.rel.RSyEq
import com.persagy.server.datacenter.models.entities.rel.RSyEqList
import com.persagy.server.services.objects.GeneralSystemService
import com.persagy.base.extensions.toJson
import com.persagy.database.SFilter
import com.persagy.service.SPageContext
import com.persagy.service.models.requests.SCountRequest
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCountResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 系统接口
 *
 * @author 张维新
 */
@Api(tags= ["009、系统"])
@RestController
@RequestMapping("/object/general-system")
open class GeneralSystemController {
    companion object {
        // 日志
        private val logger = LoggerFactory.getLogger(GeneralSystemController::class.java)
    } // Companion object

    /**
     * 创建系统信息
     *
     * @param   request         系统对象
     * @return  SCreateResponse 创建结果信息
     */
    @ApiOperation(value="创建系统信息", notes="")
    @PostMapping(value = ["/create"])
    fun create(@RequestBody request: SCreateRequest<GeneralSystem>): SCreateResponse<GeneralSystem> {
        logger.debug("generalSystem =${request.toJson()}")
      return  GeneralSystemService.createList(request)
    } // Function create()

    @ApiOperation(value="创建系统信息-处理建筑楼层", notes="")
    @PostMapping(value = ["/create-bd-fl"])
    fun createBdFl(@RequestBody request: SCreateRequest<GeneralSystem>): SCreateResponse<GeneralSystem> {
        logger.debug("generalSystem =${request.toJson()}")
        return  GeneralSystemService.createBdFl(request)
    } // Function create()

    /**
     * 根据id删除系统
     *
     * @param   idList           项目id
     * @param   idList              id数组
     * @return  SDeleteResponse()   删除的结果信息
     */
    @ApiOperation(value="根据id删除系统", notes="")
    @PostMapping(value = ["/delete"])
    fun delete(@RequestBody idList: ArrayList<GeneralSystem>): SBaseResponse {
       return GeneralSystemService.deleteByKeysList(idList)
    } // Function delete()

    /**
     * 更新系统信息
     *
     * @param   request             更新的内容对象
     * @return  SUpdateResponse()   更新的结果
     */
    @ApiOperation(value="更新系统信息", notes="")
    @PostMapping(value = ["/update"])
    fun update(@RequestBody request: SUpdateRequest<GeneralSystem>): SBaseResponse {
        logger.debug("generalSystemUpdate =${request.toJson()}")
       return  GeneralSystemService.updateList(request)
    } // Function update()

    /**
     * 查询系统信息
     *
     * @param   request         查询信息条件
     * @return  SQueryResponse  查询结果
     */
    @ApiOperation(value="查询系统信息", notes="MajorName 专业名称 ,级联查询 系统分类名（categoryNames），系统下的设备（equipmentList），系统下的竖井（shaftList），业务空间（zoneSpaceBaseTableList）")
    @PostMapping(value = ["/query"])
    fun query(@RequestBody request: SQueryRequest): SQueryResponse<GeneralSystem> {
        logger.debug("generalSystemQuery =${request.toJson()}")
        val withFilterList = ArrayList<SFilter>()
        withFilterList.add(SFilter.eq("projectId", SPageContext.getHeader("ProjectId").toString()))
       return GeneralSystemService.pageQuery(request,withFilterList)
    } // Function query()


    /**
     * 查询系统信息
     *
     * @param   request         查询信息条件
     * @return  SQueryResponse  查询结果
     */
    @ApiOperation(value="查询系统信息-系统建筑楼层一对多", notes="MajorName 专业名称 ,级联查询 系统分类名（categoryNames），系统下的设备（equipmentList），系统下的竖井（shaftList），业务空间（zoneSpaceBaseTableList）")
    @PostMapping(value = ["/query-new"])
    fun query(buildingId: String?, floorId: String?, @RequestBody request: SQueryRequest): SQueryResponse<GeneralSystem> {
        logger.debug("generalSystemQuery =${request.toJson()}")
        return GeneralSystemService.pageQuerys(buildingId, floorId, request)
    } // Function query()


    /**
     * 根据条件查询统计数量
     */
    @ApiOperation(value = "根据条件查询统计数量", notes = "例子： 根据类型查询（\"Filters\": \"category ='系统分类'\"）," +
            "根据设备类型和建筑查询（\"Filters\": \"category ='FASE';buildingId = '建筑id'\"），" +
            "根据设备类型和建筑楼层查询（\"Filters\": \"category ='FASE';buildingId = '建筑id';floorId = '楼层id'\"）")
    @PostMapping(value = ["/count"])
    fun count(@RequestBody request: SCountRequest): SCountResponse {
        val withFilterList = ArrayList<SFilter>()
        withFilterList.add(SFilter.eq("projectId", SPageContext.getHeader("ProjectId").toString()))
        return GeneralSystemService.count(request,withFilterList)
    } // Function count()

    /**
     * 查询没有和当前空间绑定的系统
     *
     * @param   type        空间类型
     * @param   spaceId     空间id
     */
    @ApiOperation(value="查询没有和当前空间绑定的系统", notes="例如：prijectId=Pj4201050001,type=AirConditioningZone spaceId=Sp4201050001df2091cdf719443b80bb737aeabf0525 " +
            "spaceId 为当前空间id type为当前空间类型 ")
    @PostMapping(value = ["/unspace-sys"])
    fun unSpaceSys( type: String, spaceId: String,@RequestBody request: SQueryRequest): SQueryResponse<GeneralSystem>{
        return GeneralSystemService.unSpaceSys(type,spaceId, request)
    } // // Function unSpaceSys()

    /**
     * 查询没有和当前系统关联的设备
     *
     * @param   sysId        系统id
     */
    @ApiOperation(value="查询没有和当前系统关联的设备", notes="sysId 为系统id")
    @PostMapping(value = ["/un-sys-equip"])
    fun unSysEquip( sysId: String,@RequestBody request: SQueryRequest): SQueryResponse<Equipment>{
        return GeneralSystemService.unSysEquip(sysId, request)
    } // Fun unSysEquip()

    /**
     * 查询没有和当前系统关联的竖井
     *
     * @param   sysId        系统id
     */
    @ApiOperation(value="查询没有和当前系统关联的竖井", notes="sysId 为系统id")
    @PostMapping(value = ["/un-sys-shaft"])
    fun unSysShaft( sysId: String,@RequestBody request: SQueryRequest): SQueryResponse<Shaft>{
        return GeneralSystemService.unSysShaft(sysId, request)
    } //  Fun unSysShaft()

    /**
     * 查询没有和当前系统关联的业务空间
     *
     * @param   sysId        系统id
     */
    @ApiOperation(value="查询没有和当前系统关联的业务空间", notes="sysId 为系统id")
    @PostMapping(value = ["/un-sys-zoneSpaceBaseTable"])
    fun unSysZoneSpaceBaseTable( sysId: String,@RequestBody request: SQueryRequest): SQueryResponse<ZoneSpace>{
        return GeneralSystemService.unSysZoneSpaceBaseTable(sysId, request)
    } // Fun unSysZoneSpaceBaseTable()

    /**
     * 创建系统下的设备关系
     */
    @ApiOperation(value = "创建系统下的设备关系", notes = "必填项：ListEquipId（设备id列表）、SysId(系统id)")
    @PostMapping(value = ["/link-equip"])
    fun createLinkEquip(@RequestBody rSyEqList: RSyEqList): SCreateResponse<RSyEq> {
        logger.debug("rSyEqList =${rSyEqList.toJson()}")
        return GeneralSystemService.createLinkEquip(rSyEqList)
    } // Function create()

//    RSyInShList
//    RSyInSpBaseList
} // Class GeneralSystemController