package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.REqForFl
import com.persagy.server.datacenter.models.entities.rel.REqForFlList
import com.persagy.server.datacenter.models.entities.rel.RFlForEqList
import com.persagy.server.services.rel.REqForFlService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 设备服务于楼层
 *
 * @author 付国宝
 */
@Api(tags = ["037、关系-设备服务于楼层"])
@RestController
@RequestMapping("/rel/eq-for-fl")
class REqForFlController {
    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(REqForFlController::class.java)
    } // Companion object

    /**
     * 创建设备服务于楼层关系
     *
     * @param   rEqForFl     设备和楼层的关系对象
     * @return               创建的结果信息
     */
    @ApiOperation(value = "创建设备服务于楼层关系", notes = "必填项：EquipId（设备id）、FloorId（楼层id）")
    @PostMapping(value = ["/link"])
    fun create(@RequestBody rEqForFl: REqForFl): SCreateResponse<REqForFl> {
        logger.debug("floor = ${rEqForFl.toJson()}")
        return REqForFlService.create(rEqForFl)
    } // Function create()

    /**
     * 根据对象删除关系
     *
     * @param   rEqForFl      对象
     * @return                删除的结果信息
     */
    @ApiOperation(value = "根据对象删除设备服务于楼层的关系，只针对一个对象", notes = "必填项：EquipId（设备id）、FloorId(楼层id)")
    @PostMapping(value = ["/unlink"])
    fun delete(@RequestBody rEqForFl: REqForFl): SBaseResponse {
        return REqForFlService.deletes(rEqForFl)
    } // Function delete()

    /**
     * 创建设备服务于楼层关系
     *
     * @param   rEqForFl    设备和楼层关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "设备服务于楼层，设备一对多", notes = "必填项：FloorIdList（楼层id列表）、EquipId（设备id）,测方法会覆盖以前的记录")
    @PostMapping(value = ["link-fl"])
    fun createFl(@RequestBody rEqForFl: REqForFlList): SCreateResponse<REqForFl>{
        logger.debug("floor =${rEqForFl.toJson()}")
        return REqForFlService.createEq(rEqForFl)
    } // Function createFl()

    /**
     * 创建服务于楼层的设备关系
     *
     * @param   rEqForFl    设备和楼层关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "服务于楼层的设备，楼层一对多",notes = "必填项：EquipIdList（设备id列表）、FloorId（建筑id），测方法会覆盖以前的记录")
    @PostMapping(value = ["link-eq"])
    fun createEq(@RequestBody rEqForFl: RFlForEqList): SCreateResponse<REqForFl>{
        logger.debug("floor =${rEqForFl.toJson()}")
        return REqForFlService.createsFl(rEqForFl)
    } // Function createSy()

} // Class REqForFlController