package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.REqInSpBase
import com.persagy.server.datacenter.models.entities.rel.RSpInEqBaseList
import com.persagy.server.services.rel.REqInSpBaseService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 设备所在业务空间
 *
 * @author 付国宝
 */
@Api(tags = ["017、关系-设备所在业务空间"])
@RestController
@RequestMapping("/rel/eq-in-sp-base")
class REqInSpController {

    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(REqInSpController::class.java)
    } // Companion object

    /**
     * 创建设备所在业务空间关系
     *
     * @param    rEqInSpBase    设备和业务空间的关系对象
     * @return                  创建的结果信息
     */
    @ApiOperation(value = "创建设备所在业务空间关系,累计添加不会覆盖以前记录", notes = "必填项：EquipId（设备id）、SpaceId（业务空间id）")
    @PostMapping(value = ["/link-list"])
    fun create(type: String, @RequestBody rEqInSpBase: SCreateRequest<REqInSpBase>): SCreateResponse<REqInSpBase> {
        logger.debug("space = ${rEqInSpBase.toJson()}")
        return REqInSpBaseService.create(type,rEqInSpBase)
    } // Function create()

    /**
     * 根据对象删除关系
     *
     * @param    rEqInSpBaseList    对象
     * @return                      删除的结果信息
     */
    @ApiOperation(value = "根据对象删除设备所在业务空间关系", notes = "必填项：EquipId（设备id）、SpaceId（业务空间id）,type为空间类型")
    @PostMapping(value = ["/unlink-list"])
    fun delete(type: String, @RequestBody rEqInSpBaseList: ArrayList<REqInSpBase>): SBaseResponse {
        return REqInSpBaseService.deletes(type,rEqInSpBaseList)
    } // Function delete()

    /**
     * 创建所在业务空间的设备关系
     *
     * @param    rEqInSpBase     设备和业务空间的关系对象
     * @return                   创建的结果信息
     */
    @ApiOperation(value = "所在业务空间的设备，业务空间一对多,累计添加不会覆盖以前记录", notes = "必填项：EquipIdList（设备id列表）、SpaceId（业务空间id）")
    @PostMapping(value = ["/link-eq-sp"])
    fun createEq(type:String, @RequestBody rEqInSpBase: RSpInEqBaseList): SCreateResponse<RSpInEqBaseList>{
        logger.debug("space = ${rEqInSpBase.toJson()}")
        return REqInSpBaseService.createsSpEq(type,rEqInSpBase)
    } // Function createEq()

} // Class REqInSpController