package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.dict.SpaceInfoDic
import com.persagy.server.datacenter.models.entities.rel.RShContainSpBase
import com.persagy.server.datacenter.models.entities.rel.RShContainSpBaseList
import com.persagy.server.services.rel.RShContainSpBaseService
import com.persagy.server.services.rel.RSpContainShBaseList
import com.persagy.base.extensions.toJson
import com.persagy.service.SPageContext
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 竖井下的业务空间
 *
 * @author 付国宝
 */
@Api(tags = ["023、关系-竖井下的业务空间"])
@RestController
@RequestMapping("/rel/sh-contain-sp-base")
class RShContainSpBaseController {

    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RShContainSpBaseController::class.java)
    } // Companion object

    /**
     * 创建竖井下的业务空间关系
     *
     * @param    rShContainSpBase    竖井和业务空间的关系对象
     * @return                       创建的结果信息
     */
    @ApiOperation(value = "创建竖井下的业务空间关系", notes = "必填项：ShaftID（竖井id）、SpaceID(业务空间id)")
    @PostMapping(value = ["/link"])
    fun create(@RequestBody rShContainSpBase: SCreateRequest<RShContainSpBase>): SCreateResponse<RShContainSpBase> {
        logger.debug("space =${rShContainSpBase.toJson()}")
        return RShContainSpBaseService.create(rShContainSpBase)
    } // Function create()

    /**
     * 根据对象删除关系
     *
     * @param    rShContainSpBase    对象
     * @param   type                 空间类型
     * @return                       删除的结果信息
     */
    @ApiOperation(value = "根据对象删除竖井下的业务空间关系，只针对一个对象", notes = "必填项：ShaftID（竖井id）、SpaceID(业务空间id)")
    @PostMapping(value = ["/unlink"])
    fun delete(type: String,@RequestBody rShContainSpBase: ArrayList<RShContainSpBase>): SBaseResponse {
        return RShContainSpBaseService.deletes(type,rShContainSpBase)
    } // Function delete()

//    /**
//     * 创建竖井下的业务空间关系
//     *
//     * @param   rShContainSpBase     竖井和业务空间的关系对象
//     * @return                       创建的结果信息
//     */
//    @ApiOperation(value = "竖井下的业务空间，竖井一对多", notes = "必填项：SpaceIdList（业务空间id列表）、ShaftID(竖井id)，此方法会覆盖以前的记录")
//    @PostMapping(value = ["link-sp"])
//    fun createSp(@RequestBody rShContainSpBase: RShContainSpBaseList): SCreateResponse<RShContainSpBase> {
//        logger.debug("space =${rShContainSpBase.toJson()}")
//        return RShContainSpBaseService.createSh(rShContainSpBase)
//    } // Function createSp()
//
//    /**
//     * 创建竖井下的业务空间关系
//     *
//     * @param    rShContainSpBase     竖井和业务空间的关系对象
//     * @return                        创建的结果信息
//     */
//    @ApiOperation(value = "业务空间关联竖井，业务空间一对多", notes = "必填项：SpaceId（业务空间id）、ShaftIDList(竖井id列表)，此方法会覆盖以前的记录")
//    @PostMapping(value = ["/link-sh"])
//    fun createSh(@RequestBody rShContainSpBase: RSpContainShBaseList): SCreateResponse<RShContainSpBase> {
//        logger.debug("space =${rShContainSpBase.toJson()}")
//        return RShContainSpBaseService.createsSp(rShContainSpBase)
//    } // Function createSh()


    /**
     * 创建竖井下的业务空间关系
     *
     * @param   rShContainSpBase     竖井和业务空间的关系对象
     * @param   type                 空间类型
     * @return                       创建的结果信息
     */
    @ApiOperation(value = "竖井下的业务空间，竖井一对多，此方法不会覆盖以前的记录", notes = "必填项：SpaceIdList（业务空间id列表）、ShaftID(竖井id)，此方法不会覆盖以前的记录")
    @PostMapping(value = ["link-shsps"])
    fun createShSps(type: String?,@RequestBody rShContainSpBase: RShContainSpBaseList): SCreateResponse<RShContainSpBaseList> {
        logger.debug("space =${rShContainSpBase.toJson()}")
        return RShContainSpBaseService.createShSps(type,rShContainSpBase)
    } // Function createSp()

    /**
     * 创建竖井下的业务空间关系
     *
     * @param   rSpContainShBase     竖井和业务空间的关系对象
     * @param   type                 空间类型
     * @return                       创建的结果信息
     */
    @ApiOperation(value = "竖井下的业务空间，空间一对多，此方法不会覆盖以前的记录", notes = "必填项：SpaceId（业务空间id）、ShaftIDList(竖井id列表)，此方法不会覆盖以前的记录")
    @PostMapping(value = ["link-spshs"])
    fun createSpShs(type: String,@RequestBody rSpContainShBase: RSpContainShBaseList): SCreateResponse<RSpContainShBaseList> {
        logger.debug("space =${rSpContainShBase.toJson()}")
        return RShContainSpBaseService.createSpShs(type,rSpContainShBase)
    } // Function createSp()

    /**
     * 创建竖井下的业务空间关系
     *
     * @param   rShContainSpBase     竖井和业务空间的关系对象
     * @param   type                 空间类型
     * @return                       创建的结果信息
     */
    @ApiOperation(value = "竖井下的业务空间，竖井一对多，此方法会覆盖以前的记录", notes = "必填项：SpaceIdList（业务空间id列表）、ShaftID(竖井id)，此方法会覆盖以前的记录")
    @PostMapping(value = ["link-shsps-replace"])
    fun createShSpsReplace(Type: String,BuildingId: String,FloorId: String, @RequestBody rShContainSpBase: RShContainSpBaseList): SCreateResponse<RShContainSpBaseList> {
        logger.debug("space =${rShContainSpBase.toJson()}")
        return RShContainSpBaseService.createShSpsReplace(Type,BuildingId,FloorId,rShContainSpBase)
    } // Function createSp()



    /**
     * 查询空间类型和名称
     * @param shaftId 竖井id
     */
    @ApiOperation(value = "查询空间类型和名称",notes = "")
    @PostMapping(value = ["/space-type-query"])
    fun spaceTypeQuery(shaftId: String): SQueryResponse<SpaceInfoDic> {
        val projectId = SPageContext.getHeader("ProjectId").toString()
        return RShContainSpBaseService.spaceTypeQuery(projectId,shaftId)
    } // Function spaceTypeQuery()

} // Class RShContainSpBaseController