package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.REqSyList
import com.persagy.server.datacenter.models.entities.rel.RSyEq
import com.persagy.server.datacenter.models.entities.rel.RSyEqList
import com.persagy.server.services.rel.RSyEqService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 *系统下的设备设施
 *
 * @author 张维新
 */
@Api(tags = ["019、关系-系统下的设备设施"])
@RestController
@RequestMapping("/rel/sy-in-eq")
class RSyEqController {
    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RSyEqController::class.java)
    } // Companion object

    /**
     * 创建系统下的设备关系
     *
     * @param   rSyEq           系统和设备的关系对象
     * @return                  创建结果信息
     */
    @ApiOperation(value = "创建系统下的设备关系", notes = "必填项：EquipID（设备id）、SysID(系统id)")
    @PostMapping(value = ["/link"])
    fun create(@RequestBody rSyEq: RSyEq): SCreateResponse<RSyEq> {
        logger.debug("equip =${rSyEq.toJson()}")
        return RSyEqService.create(rSyEq)
    } // Function create()

    /**
     * 根据对象删除关系
     *
     * @param   rSyEq      对象
     * @return             删除的结果信息
     */
    @ApiOperation(value = "根据对象删除系统和设备的关系，只针对一个对象", notes = "必填项：EquipID（设备id）、SysID(系统id)")
    @PostMapping(value = ["/unlink"])
    fun delete(@RequestBody rSyEq: RSyEq): SBaseResponse {
        return RSyEqService.deletes(rSyEq)
    } // Function delete()

    /**
     * 创建系统下的设备关系
     *
     * @param   rSyEq           系统和设备的关系对象
     * @return                  创建结果信息
     */
    @ApiOperation(value = "系统下的设备，系统一对多，数据覆盖", notes = "必填项：EquipIdList（设备id列表）、SysID(系统id)，测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-eq"])
    fun createEq(@RequestBody rSyEq: RSyEqList): SCreateResponse<RSyEq> {
        logger.debug("equip =${rSyEq.toJson()}")
        return RSyEqService.createSy(rSyEq)
    } // Function createEq()

    /**
     * 创建系统下的设备关系
     *
     * @param   rSyEq           系统和设备的关系对象
     * @return                  创建结果信息
     */
    @ApiOperation(value = "设备关联系统，设备一对多， 数据覆盖", notes = "必填项：EquipId（设备id）、sysIdList(系统id列表)，测方法会覆盖以前的记录")
    @PostMapping(value = ["/link-sy"])
    fun createSy(@RequestBody rSyEq: REqSyList): SCreateResponse<RSyEq> {
        logger.debug("equip =${rSyEq.toJson()}")
        return RSyEqService.createsEq(rSyEq)
    } // Function createSy()

    /**
     * 创建系统下的设备关系
     *
     * @param   rSyEq           系统和设备的关系对象
     * @return                  创建结果信息
     */
    @ApiOperation(value = "设备关联系统，系统一对多,数据叠加", notes = "必填项：EquipId（设备id）、sysIdList(系统id列表)，此方法会为累计叠加，不会覆盖以前的数据")
    @PostMapping(value = ["/link-sy-eq"])
    fun createSyEq(@RequestBody rSyEq: RSyEqList): SCreateResponse<RSyEq> {
        logger.debug("equip =${rSyEq.toJson()}")
        return RSyEqService.createSyEq(rSyEq)
    } // Function createSyEq()

    /**
     * 根据对象删除系统和设备的关系
     *
     * @param   rSyEq           根据对象删除系统和设备的关系
     * @return                  创建结果信息
     */
    @ApiOperation(value = "根据对象删除系统和设备的关系", notes = "必填项：EquipID（设备id）、SysID(系统id)")
    @PostMapping(value = ["/unlinks-sy-eq"])
    fun deleteRSyEq(@RequestBody idList: ArrayList<RSyEq>): SBaseResponse {
        logger.debug("equip =${idList.toJson()}")
        return RSyEqService.deleteByKeysList(idList)
    } // Function deleteRSyEq()

} // Class RSyEqController