package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.RBdForSyList
import com.persagy.server.datacenter.models.entities.rel.RSyForBd
import com.persagy.server.datacenter.models.entities.rel.RSyForBdList
import com.persagy.server.services.rel.RSyForBdService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 系统服务于建筑
 *
 * @author 付国宝
 */
@Api(tags = ["026、关系-系统服务于建筑"])
@RestController
@RequestMapping("/rel/sy-for-bd")
class RSyForBdController {
    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RSyForBdController::class.java)
    } // Companion object

    /**
     * 创建系统服务于建筑关系
     *
     * @param   rSyForBd     系统和建筑的关系对象
     * @return               创建的结果信息
     */
    @ApiOperation(value = "创建系统服务于建筑关系", notes = "必填项：SysId（系统id）、BuildingId（建筑id）")
    @PostMapping(value = ["/link"])
    fun create(@RequestBody rSyForBd: RSyForBd): SCreateResponse<RSyForBd>{
        logger.debug("build = ${rSyForBd.toJson()}")
        return RSyForBdService.create(rSyForBd)
    } // Function create()

    /**
     * 根据对象删除关系
     *
     * @param   rSyForBd      对象
     * @return                删除的结果信息
     */
    @ApiOperation(value = "根据对象删除系统服务于建筑的关系，只针对一个对象", notes = "必填项：SysId（系统id）、BuildingId(建筑id)")
    @PostMapping(value = ["/unlink"])
    fun delete(@RequestBody rSyForBd: RSyForBd): SBaseResponse {
        return RSyForBdService.deletes(rSyForBd)
    } // Function delete()

    /**
     * 创建系统服务于建筑关系
     *
     * @param   rSyForBd    系统和建筑关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "系统服务于建筑，系统一对多", notes = "必填项：BuildingIdList（建筑id列表）、SysId（系统id）,测方法会覆盖以前的记录")
    @PostMapping(value = ["link-bd"])
    fun createBd(@RequestBody rSyForBd: RSyForBdList): SCreateResponse<RSyForBd>{
        logger.debug("build =${rSyForBd.toJson()}")
        return RSyForBdService.createSy(rSyForBd)
    } // Function createBd()

    /**
     * 创建服务于建筑的系统关系
     *
     * @param   rSyForBd    系统和建筑关系对象
     * @return              创建的结果信息
     */
    @ApiOperation(value = "服务于建筑的系统，建筑一对多",notes = "必填项：sysIdList（系统id列表）、BuildingId（建筑id），测方法会覆盖以前的记录")
    @PostMapping(value = ["link-sy"])
    fun createSy(@RequestBody rSyForBd: RBdForSyList): SCreateResponse<RSyForBd>{
        logger.debug("build =${rSyForBd.toJson()}")
        return RSyForBdService.createsBd(rSyForBd)
    } // Function createSy()

} // Class RSyForBdController