package com.persagy.server.controllers.rel

import com.persagy.server.datacenter.models.entities.rel.RSpInSyBaseList
import com.persagy.server.datacenter.models.entities.rel.RSyInSpBase
import com.persagy.server.datacenter.models.entities.rel.RSyInSpBaseList
import com.persagy.server.services.rel.RSyInSpBaseService
import com.persagy.base.extensions.toJson
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 系统所在业务空间
 *
 * @author 张维新
 */
@Api(tags = ["033、关系-系统所在业务空间"])
@RestController
@RequestMapping("/rel/sy-in-sp-base")
class RSyInSpController {

    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(RSyInSpController::class.java)
    } // Companion object

    /**
     * 创建系统所在业务空间关系
     *
     * @param   rSyInSpBase   系统和业务空间的关系对象
     * @return                创建的结果信息
     */
    @ApiOperation(value = "创建系统所在业务空间关系", notes = "必填项：SysID（系统id）、SpaceID(业务空间id)")
    @PostMapping(value = ["/link-list"])
    fun create( @RequestBody rSyInSpBase: SCreateRequest<RSyInSpBase>): SCreateResponse<RSyInSpBase> {
        logger.debug("space =${rSyInSpBase.toJson()}")
        return RSyInSpBaseService.create(rSyInSpBase)
    } // Functio create()

    /**
     * 根据对象删除关系
     *
     * @param   rSyInSpBase       对象
     * @return                    删除的结果信息
     */
    @ApiOperation(value = "根据对象删除系统所在业务空间关系", notes = "必填项：SysID（系统id）、SpaceID(业务空间id)")
    @PostMapping(value = ["/unlink-list"])
    fun delete(type: String,@RequestBody rSyInSpBase: ArrayList<RSyInSpBase>): SBaseResponse {
        return RSyInSpBaseService.deletes(type,rSyInSpBase)
    } // Function delete()

//    /**
//     * 创建系统所在业务空间关系
//     *
//     * @param    rSyInSpBase    系统和业务空间的关系对象
//     * @return                  创建的结果信息
//     */
//    @ApiOperation(value = "系统所在业务空间关系，系统一对多", notes = "必填项：SpaceIdList（业务空间id列表）、SysID(系统id)，测方法会覆盖以前的记录")
//    @PostMapping(value = ["/link-sp"])
//    fun createSp(@RequestBody rSyInSpBase: RSyInSpBaseList): SCreateResponse<RSyInSpBase> {
//        logger.debug("space =${rSyInSpBase.toJson()}")
//        return RSyInSpBaseService.createSy(rSyInSpBase)
//    } // Function createSp()

    /**
     * 创建系统所在的业务空间关系 此方法不会覆盖以前的记录，累计叠加
     *
     * @param   rSyInSpBase            系统和业务空间的关系对象
     * @return                               创建的结果信息
     */
    @ApiOperation(value = " 处理所有空间分区和系统关系 系统所在的业务空间关系，空间分区一对多，累计叠加，不覆盖", notes = "必填项：SpaceId（业务空间id）、SysIDList(系统id列表)，此方法不会覆盖以前的记录，累计叠加")
    @PostMapping(value = ["/link-sp-sys"])
    fun createsSpSys(type: String,@RequestBody rSyInSpBase: RSpInSyBaseList): SCreateResponse<RSpInSyBaseList> {
        logger.debug("space =${rSyInSpBase.toJson()}")
        return RSyInSpBaseService.createsSpSys(type,rSyInSpBase)
    } // Function createSy()

    /**
     * 创建系统所在业务空间关系
     *
     * @param    rSyInSpBase    系统和业务空间的关系对象
     * @return                  创建的结果信息
     */
    @ApiOperation(value = "系统所在业务空间关系，系统一对多，不覆盖", notes = "必填项：SpaceIdList（业务空间id列表）、SysID(系统id)，此方法不会覆盖以前的记录")
    @PostMapping(value = ["/link-sy-sps"])
    fun createSySps(type: String,@RequestBody rSyInSpBase: RSyInSpBaseList): SCreateResponse<RSyInSpBaseList> {
        logger.debug("space =${rSyInSpBase.toJson()}")
        return RSyInSpBaseService.createSySps(type,rSyInSpBase)
    } // Function createSySps()

} // Class RSyInSpBaseController