package com.persagy.server.services.assistant

import com.persagy.database.SFilter
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.datacenter.models.entities.objects.Equipment
import com.persagy.server.datacenter.models.entities.objects.ZoneSpace
import com.persagy.server.datacenter.models.entities.rel.RSpinBd
import com.persagy.server.datacenter.models.entities.rel.RSpinFl
import com.persagy.server.datacenter.models.requests.UpDataFloorAndBuildingRequests
import com.persagy.server.services.base.Service
import com.persagy.server.services.objects.FloorService
import com.persagy.server.services.objects.ZoneSpaceBaseService
import com.persagy.server.services.rel.RSpInBdService
import com.persagy.server.services.rel.RSpInFlService
import com.persagy.service.SPageContext
import com.persagy.service.models.enums.SResponseType
import com.persagy.service.models.responses.SBaseResponse
import org.json.JSONObject

/**
 * 修改关系 楼层或建下的对象
 *
 * @author 张维新
 */
object UpDataFloorAndBuildingServuce : Service<Equipment>(SMybatisDao(Equipment::class.java)) {


    /**
     * 修改空间对象的楼层建筑信息
     *
     * @param   spaceId     业务空间id
     * @param   id          楼层或建筑id
     * @param   type        业务空间类型
     */
    fun upDataFloorORBuilding(upDataFloorAndBuildingRequestsList: ArrayList<UpDataFloorAndBuildingRequests>): SBaseResponse {
        try {
            val projectId = SPageContext.getHeader("ProjectId")

            if (upDataFloorAndBuildingRequestsList.isNullOrEmpty()) {
                val sBaseResponse = SBaseResponse(SResponseType.failure)
                sBaseResponse.message = "不可以传入空数据"
                return sBaseResponse
            }
            for (upDataFloorAndBuildingRequests in upDataFloorAndBuildingRequestsList) {

                val spaceId = upDataFloorAndBuildingRequests.spaceId
                val id = upDataFloorAndBuildingRequests.id
                val type = upDataFloorAndBuildingRequests.type

                try {
                    if (!id.isNullOrEmpty()) {
                        if (id.startsWith("Fl")) {
                            val floor =
                                FloorService.select(SFilter.eq("projectId", projectId!!), SFilter.eq("FloorID", id))
                                    .entity()

                            if (floor != null) {
                                /** 清除空间和建筑楼层的的数据 */
                                RSpInBdService.delete(
                                    SFilter.eq("projectId", projectId!!),
                                    SFilter.eq("spaceId", spaceId!!)
                                )
                                RSpInFlService.delete(
                                    SFilter.eq("projectId", projectId!!),
                                    SFilter.eq("spaceId", spaceId!!)
                                )
                                val rSpinFl = RSpinFl()
                                rSpinFl.floorId = floor.id
                                rSpinFl.projectId = projectId
                                rSpinFl.spaceId = spaceId
                                rSpinFl.objectType = type
                                rSpinFl.sign = 1
                                RSpInFlService.replace(rSpinFl)

                                val rSpinBd = RSpinBd()
                                rSpinBd.objectType = type
                                rSpinBd.buildingId = floor.buildId
                                rSpinBd.spaceId = spaceId
                                rSpinBd.sign = 1
                                rSpinBd.projectId = projectId
                                RSpInBdService.replace(rSpinBd)
                            }

                        } else if (id.startsWith("Bd")) {
                            /** 清除空间和建筑楼层的的数据 */
                            RSpInBdService.delete(
                                SFilter.eq("projectId", projectId!!),
                                SFilter.eq("spaceId", spaceId!!)
                            )
                            RSpInFlService.delete(
                                SFilter.eq("projectId", projectId!!),
                                SFilter.eq("spaceId", spaceId!!)
                            )
                            val rSpinBd = RSpinBd()
                            rSpinBd.objectType = type
                            rSpinBd.buildingId = id
                            rSpinBd.spaceId = spaceId
                            rSpinBd.sign = 1
                            rSpinBd.projectId = projectId
                            RSpInBdService.replace(rSpinBd)
                        }
                    } else {
                        /** 清除空间和建筑楼层的的数据 */
                        RSpInBdService.delete(SFilter.eq("projectId", projectId!!), SFilter.eq("spaceId", spaceId!!))
                        RSpInFlService.delete(SFilter.eq("projectId", projectId!!), SFilter.eq("spaceId", spaceId!!))
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }


                val zonePowerSupply = ZoneSpace()
                zonePowerSupply.id = spaceId
                if (!id.isNullOrEmpty()) {
                    if (id.startsWith("Fl")) {
                        zonePowerSupply.floorId = id
                        val floor = FloorService.select(SFilter.eq("projectId", projectId!!), SFilter.eq("FloorID", id))
                            .entity()
                        zonePowerSupply.buildingId = floor?.buildId
                        val list = ArrayList<String>()
                        list.add("FloorId")
                        list.add("BuildingId")
                        ZoneSpaceBaseService.update(zonePowerSupply, list)
                    } else if (id.startsWith("Bd")) {
                        val list = ArrayList<String>()
                        list.add("FloorId")
                        list.add("BuildingId")
                        zonePowerSupply.buildingId = id
                        zonePowerSupply.floorId = null
                        ZoneSpaceBaseService.update(zonePowerSupply, list)
                    }
                } else {
                    /** 清空建筑楼层 */
                    val list = ArrayList<String>()
                    list.add("FloorId")
                    list.add("BuildingId")
                    zonePowerSupply.buildingId = null
                    zonePowerSupply.floorId = null
                    ZoneSpaceBaseService.update(zonePowerSupply, list)
                }
                /** 发送消息 */
                sendMessages(projectId!!, spaceId!!, id)
            }
            return SBaseResponse(SResponseType.success)
        } catch (e: Exception) {
            e.printStackTrace()
            return SBaseResponse(SResponseType.failure)
        }

    } // Function upDataFloorORBuilding

    /**
     * 发送消息
     *
     * @param   projectId   项目id
     * @param   spaceId     业务空间id
     * @param   id          楼层或建筑id
     */
    fun sendMessages(projectId: String, spaceId: String, id: String?) {
        try {
            val jsonObject = JSONObject()
            jsonObject.put("type", "20")
            jsonObject.put("projectId", projectId)
            jsonObject.put("id", spaceId)
            jsonObject.put("linkId", id)
            /** 发送消息 */
            messageHandler.sendMessage(jsonObject.toString())
        } catch (e: Exception) {
            e.printStackTrace()
        }
    } // Function sendMessages

} // Object UpDataFloorAndBuildingServuce