package com.persagy.server.services.rel

import com.persagy.server.synchronize.MessageHandler
import com.persagy.server.datacenter.models.entities.rel.RSpInTnBaseList
import com.persagy.server.datacenter.models.entities.rel.RTn2Sp
import com.persagy.server.datacenter.models.entities.rel.RTnInSpBase
import com.persagy.server.datacenter.models.entities.rel.RTnInSpBaseList
import com.persagy.base.extensions.toJson
import com.persagy.mybatis.SMybatisDao
import com.persagy.service.SBaseService
import com.persagy.service.SObjectService
import com.persagy.service.SPageContext
import com.persagy.service.models.enums.SResponseType
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.utils.SSpringContextUtil
import org.json.JSONObject

/**
 * 租户所租用的业务空间关系服务
 *
 * @author 付国宝
 */
object RTnInSpBaseService: SBaseService<RTnInSpBase>(SMybatisDao(RTnInSpBase::class.java)) {


    /** 租户和业务空间的关系 */
    var rTn2SpService = SObjectService(SMybatisDao(RTn2Sp::class.java))

    /** MQ消息对象 */
    private val messageHandler by lazy {
        SSpringContextUtil.getBean(MessageHandler::class.java) as MessageHandler
    }

    /**
     * 创建租户所租用的业务空间关系
     *
     * @param    rTnInSpBase    租户所租用的业务空间关系对象
     */
    fun create(type: String,rTnInSpBaseList: SCreateRequest<RTnInSpBase>): SCreateResponse<RTnInSpBase> {
        return try {
            val projectId = SPageContext.getHeader("ProjectId")
            if (!rTnInSpBaseList.content.isNullOrEmpty()){
                for (rTnInSpBase in rTnInSpBaseList.content){
                    val rTn2Sp = RTn2Sp()
                    rTn2Sp.id2 = rTnInSpBase.spaceId
                    rTn2Sp.id1 = rTnInSpBase.tenantId
                    rTn2Sp.projectId = projectId
                    rTn2Sp.sign = 1
                    rTn2Sp.zoneType = type
                    rTn2Sp.type = "tn2sp"
                    val insert = rTn2SpService.insert(rTn2Sp)
                    if (insert){
                        try {
                            val jsonObject = JSONObject()
                            jsonObject.put("type", "10")
                            jsonObject.put("projectId", projectId)
                            jsonObject.put("id", rTnInSpBase.tenantId)
                            jsonObject.put("linkId", rTnInSpBase.spaceId)
                            jsonObject.put("obj_type", "TenentInArch")
                            /** 发送消息 */
                            messageHandler.sendMessage(jsonObject.toString())
                        } catch (e: Exception) {
                            e.printStackTrace()
                        }
                    }
                }
            }
            SCreateResponse(SResponseType.success)

//            if (type == "HeatingZone"){
//                val list = ArrayList<RTnInSpZoneHeating>()
//                if (!rTnInSpBaseList.content.isNullOrEmpty()){
//                    for (rTnInSpBase in rTnInSpBaseList.content){
//                        val rTnInSpZoneHeating = RTnInSpZoneHeating()
//                        rTnInSpZoneHeating.spaceId = rTnInSpBase.spaceId
//                        rTnInSpZoneHeating.tenantId = rTnInSpBase.tenantId
//                        list.add(rTnInSpZoneHeating)
//                    }
//                }
//                RTnInSpZoneHeatingService.create(list)
//            }else if (type == "CleanZone"){
//                val list = ArrayList<RTnInSpZoneClean>()
//                if (!rTnInSpBaseList.content.isNullOrEmpty()){
//                    for (rTnInSpBase in rTnInSpBaseList.content){
//                        val rTnInSpZoneHeating = RTnInSpZoneClean()
//                        rTnInSpZoneHeating.spaceId = rTnInSpBase.spaceId
//                        rTnInSpZoneHeating.tenantId = rTnInSpBase.tenantId
//                        list.add(rTnInSpZoneHeating)
//                    }
//                }
//                RTnInSpZoneCleanService.create(list)
//            }
////            else if (type == "DomesticWaterSupplyZone"){
////                RTnInSpZoneDomesticWaterSupplyService.createTn(rTnInSpBaseList)
////            }else if (type == "NetworkZone" ){
////                RTnInSpZoneNetworkService.createTn(rTnInSpBaseList)
////            }
//            else if (type == "TenantZone"){
//                val list = ArrayList<RTnInSpZoneTenant>()
//                if (!rTnInSpBaseList.content.isNullOrEmpty()){
//                    for (rTnInSpBase in rTnInSpBaseList.content){
//                        val rTnInSpZoneHeating = RTnInSpZoneTenant()
//                        rTnInSpZoneHeating.spaceId = rTnInSpBase.spaceId
//                        rTnInSpZoneHeating.tenantId = rTnInSpBase.tenantId
//                        list.add(rTnInSpZoneHeating)
//                    }
//                }
//
//                RTnInSpZoneTenantService.create(list)
//            }
////            else if (type == "AirConditioningZone"){
////                RTnInSpZoneAirConditioningService.createTn(rTnInSpBaseList)
////            }else if (type == "FunctionZone"){
////                RTnInSpZoneFunctionService.createTn(rTnInSpBaseList)
////            }else if (type == "FireZone"){
////                RTnInSpZoneFireService.createTn(rTnInSpBaseList)
////            }else if (type == "SecurityZone"){
////                RTnInSpZoneSecurityService.createTn(rTnInSpBaseList)
////            }
//            else if (type == "GeneralZone"){
//                val list = ArrayList<RTnInSpZoneGeneral>()
//                if (!rTnInSpBaseList.content.isNullOrEmpty()){
//                    for (rTnInSpBase in rTnInSpBaseList.content){
//                        val rTnInSpZoneHeating = RTnInSpZoneGeneral()
//                        rTnInSpZoneHeating.spaceId = rTnInSpBase.spaceId
//                        rTnInSpZoneHeating.tenantId = rTnInSpBase.tenantId
//                        list.add(rTnInSpZoneHeating)
//                    }
//                }
//
//                RTnInSpZoneGeneralService.create(list)
//            }
////            else if (type == "PowerSupplyZone"){
////                RTnInSpZonePowerSupplyService.createTn(rTnInSpBaseList)
////            }else if (type == "LightingZone"){
////                RTnInSpZoneLightingService.createTn(rTnInSpBaseList)
////            }
//            else{
//                val sCreateResponse = SCreateResponse<RTnInSpBase>(SResponseType.failure)
//                sCreateResponse.message = "空间分区类型不存在：$type"
//                sCreateResponse
//            }
        } catch (e: Exception) {
            e.printStackTrace()
            SCreateResponse(SResponseType.failure,e.message.toString())
        }
    } // Function create()

    /**
     * 根据对象删除
     *
     * @param   rTnInSpBase    关系对象实例
     * @return
     */
    fun deletes(type: String,rTnInSpBaseList: ArrayList<RTnInSpBase>): SBaseResponse {
        return try {
            val projectId = SPageContext.getHeader("ProjectId")
            for (rTnInSpBase in rTnInSpBaseList) {
                val rTn2Sp = RTn2Sp()
                rTn2Sp.id1 = rTnInSpBase.tenantId
                rTn2Sp.id2 = rTnInSpBase.spaceId
                rTn2Sp.zoneType = type
                rTn2Sp.projectId = projectId
                rTn2Sp.type = "tn2sp"
                val delete = rTn2SpService.delete(rTn2Sp)
                if (delete){
                    val jsonObject = JSONObject()
                    jsonObject.put("type", "12")
                    jsonObject.put("projectId", projectId)
                    jsonObject.put("id", rTnInSpBase.tenantId)
                    jsonObject.put("obj_type", "TenentInArch")
                    jsonObject.put("linkId",rTnInSpBase.spaceId)

                    /** 发送消息 */
                    messageHandler.sendMessage(jsonObject.toString())
                }
            }
            val sBaseResponse = SBaseResponse(SResponseType.success)
            sBaseResponse
//            val isDelete = delete(rTnInSpBase)
//            /** 删除成功 */
//            if (isDelete) {
//                val sBaseResponse = SBaseResponse(SResponseType.success)
//                sBaseResponse.message = rTnInSpBase.toJson()
//                sBaseResponse
//            } else {
//                SBaseResponse(SResponseType.failure)
//            }

//            if (type == "HeatingZone"){
//                RTnInSpZoneHeatingService.deletes(rTnInSpBaseList)
//            }else if (type == "CleanZone"){
//                RTnInSpZoneCleanService.deletes(rTnInSpBaseList)
//            }else if (type == "DomesticWaterSupplyZone"){
//                RTnInSpZoneDomesticWaterSupplyService.deletes(rTnInSpBaseList)
//            }else if (type == "NetworkZone" ){
//                RTnInSpZoneNetworkService.deletes(rTnInSpBaseList)
//            }else
//                if (type == "TenantZone"){
//                val list = ArrayList<RTnInSpZoneTenant>()
//               for (rTnInSpBase in rTnInSpBaseList){
//                   val rTnInSpZoneTenant = RTnInSpZoneTenant()
//                   rTnInSpZoneTenant.tenantId = rTnInSpBase.tenantId
//                   rTnInSpZoneTenant.spaceId = rTnInSpBase.spaceId
//                   list.add(rTnInSpZoneTenant)
//               }
//
//                RTnInSpZoneTenantService.deletes(list)
//            }
//                else if (type == "AirConditioningZone"){
//                RTnInSpZoneAirConditioningService.deletes(rTnInSpBaseList)
//            }else if (type == "FunctionZone"){
//                RTnInSpZoneFunctionService.deletes(rTnInSpBaseList)
//            }else if (type == "FireZone"){
//                RTnInSpZoneFireService.deletes(rTnInSpBaseList)
//            }else if (type == "SecurityZone"){
//                RTnInSpZoneSecurityService.deletes(rTnInSpBaseList)
//            }
//                else if (type == "GeneralZone"){
//                    val list = ArrayList<RTnInSpZoneGeneral>()
//                    for (rTnInSpBase in rTnInSpBaseList){
//                        val rTnInSpZoneTenant = RTnInSpZoneGeneral()
//                        rTnInSpZoneTenant.tenantId = rTnInSpBase.tenantId
//                        rTnInSpZoneTenant.spaceId = rTnInSpBase.spaceId
//                        list.add(rTnInSpZoneTenant)
//                    }
//
//                RTnInSpZoneGeneralService.deletes(list)
//            }
//                else if (type == "PowerSupplyZone"){
//                RTnInSpZonePowerSupplyService.deletes(rTnInSpBaseList)
//            }else if (type == "LightingZone"){
//                RTnInSpZoneLightingService.deletes(rTnInSpBaseList)
//            }
//                else{
//                val sCreateResponse = SCreateResponse<RTnInSpBase>(SResponseType.failure)
//                sCreateResponse.message = "空间分区类型不存在：$type"
//                sCreateResponse
//            }
        } catch (e: Exception) {
            e.printStackTrace()
            return SBaseResponse(SResponseType.failure, e.message!!)
        }
    } // Function deletes()

    /**
     * 创建租户所租用的业务空间关系
     *
     * @param   rTnInSpBaseList    租户所租用的业务空间关系对象列表
     */
    fun createTn(type: String, rTnInSpBaseList: RTnInSpBaseList): SCreateResponse<RTnInSpBase> {
        return try {

            /** 成功集合 */
            val successList = ArrayList<Any>()
            /** 失败集合 */
            val failureList = ArrayList<Any>()
            rTn2SpService.delete("Id1 = '${rTnInSpBaseList.tenantId}'")
            val projectId = SPageContext.getHeader("ProjectId")
            for (spaceId in rTnInSpBaseList.spaceIdList!!){
                val rTn2Sp = RTn2Sp()
                rTn2Sp.id1 = rTnInSpBaseList.tenantId
                rTn2Sp.id2 = spaceId
                rTn2Sp.projectId = projectId
                rTn2Sp.sign = 1
                rTn2Sp.zoneType = type
                rTn2Sp.type = "tn2sp"
                val replace = rTn2SpService.replace(rTn2Sp)
                if (replace){
                    successList.add(rTn2Sp)
                }else{
                    failureList.add(rTn2Sp)
                }
            }
            if (successList.size>0){
                val sCreateResponse = SCreateResponse<RTnInSpBase>(SResponseType.success)
                if (failureList.size>0){
                    sCreateResponse.message ="失败对象："+failureList.toJson()
                }
                sCreateResponse
            }else{
                SCreateResponse(SResponseType.failure)
            }



//            if (type == "HeatingZone"){
//                RTnInSpZoneHeatingService.createTn(rTnInSpBaseList)
//            }else if (type == "CleanZone"){
//                RTnInSpZoneCleanService.createTn(rTnInSpBaseList)
//            }else if (type == "DomesticWaterSupplyZone"){
//                RTnInSpZoneDomesticWaterSupplyService.createTn(rTnInSpBaseList)
//            }else if (type == "NetworkZone" ){
//                RTnInSpZoneNetworkService.createTn(rTnInSpBaseList)
//            }else if (type == "TenantZone"){
//                RTnInSpZoneTenantService.createTn(rTnInSpBaseList)
//            }else if (type == "AirConditioningZone"){
//                RTnInSpZoneAirConditioningService.createTn(rTnInSpBaseList)
//            }else if (type == "FunctionZone"){
//                RTnInSpZoneFunctionService.createTn(rTnInSpBaseList)
//            }else if (type == "FireZone"){
//                RTnInSpZoneFireService.createTn(rTnInSpBaseList)
//            }else if (type == "SecurityZone"){
//                RTnInSpZoneSecurityService.createTn(rTnInSpBaseList)
//            }else if (type == "GeneralZone"){
//                RTnInSpZoneGeneralService.createTn(rTnInSpBaseList)
//            }else if (type == "PowerSupplyZone"){
//                RTnInSpZonePowerSupplyService.createTn(rTnInSpBaseList)
//            }else if (type == "LightingZone"){
//                RTnInSpZoneLightingService.createTn(rTnInSpBaseList)
//            }else{
//                val sCreateResponse = SCreateResponse<RTnInSpBase>(SResponseType.failure)
//                sCreateResponse.message = "空间分区类型不存在：$type"
//                sCreateResponse
//            }
        } catch (e: Exception) {
            e.printStackTrace()
            SCreateResponse(SResponseType.failure,e.message.toString())
        }
    } // Function createTn()

    /**
     * 创建所租用的业务空间的租户关系
     *
     * @param     rTnInSpBaseList       所租用的业务空间的租户关系对象列表
     */
    fun createsSp(rTnInSpBaseList: RSpInTnBaseList): SCreateResponse<RTnInSpBase> {
        return try {
            /** 成功集合 */
            val successList = ArrayList<Any>()
            /** 失败集合 */
            val failureList = ArrayList<Any>()
            rTn2SpService.delete("Id2 = '${rTnInSpBaseList.spaceId}'")
            val projectId = SPageContext.getHeader("ProjectId")
            for (tenantId in rTnInSpBaseList.tenantIdList!!){
                val rTn2Sp = RTn2Sp()
                rTn2Sp.id2 = rTnInSpBaseList.spaceId
                rTn2Sp.id1 = tenantId
                rTn2Sp.projectId = projectId
                rTn2Sp.sign = 1
                rTn2Sp.zoneType = rTnInSpBaseList.zoneType
                rTn2Sp.type = "tn2sp"
                val replace = rTn2SpService.replace(rTn2Sp)
                if (replace){
                    successList.add(rTn2Sp)
                }else{
                    failureList.add(rTn2Sp)
                }
            }
            if (successList.size>0){
                if (failureList.size>0){
                    val sCreateResponse = SCreateResponse<RTnInSpBase>(SResponseType.success)
                    sCreateResponse.message ="失败对象："+failureList.toJson()
                    sCreateResponse
                }else{
                    val sCreateResponse = SCreateResponse<RTnInSpBase>(SResponseType.success)
                    sCreateResponse
                }
            }else{
                SCreateResponse(SResponseType.failure)
            }
        } catch (e:Exception){
            e.printStackTrace()
            SCreateResponse(SResponseType.failure,e.message.toString())
        }
    } // Function createsSp()

} // Object RTnInSpBaseService