package com.persagy.server.labsl.controller

import com.persagy.server.labsl.models.entities.Markers
import com.persagy.server.labsl.services.MarkersService
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 文本注释，图上的图片说明
 *
 * @author wx
 */
@Api(tags = ["003、文本注释，图上的图片说明"])
@RestController
@RequestMapping("/marker")
class MarkersController {

    /**
     * 注释说明
     *
     * @param   request     待创建注释说明对象列表
     * @return  创建完成注释说明对象列表
     */
    @ApiOperation(value="注释说明创建", notes="")
    @PostMapping("/create")
    fun create(@RequestBody request: SCreateRequest<Markers>): SCreateResponse<Markers> {
        return MarkersService.createList(request)
    } // Function create()

    /**
     * 根据id删除图注释说明
     *
     * @param   idList      id数组
     * @return              删除的结果信息
     */
    @ApiOperation(value = "根据id删注释说明信息", notes = "")
    @PostMapping(value = ["/delete"])
    fun delete(@RequestBody idList: ArrayList<Markers>): SBaseResponse {
        return MarkersService.deleteByKeysList(idList)
    } // Function delete()

    /**
     * 更新注释说明信息
     *
     * @param   request        更新的内容对象
     * @return                  更新的结果
     */
    @ApiOperation(value = "更新注释说明信息", notes = "")
    @PostMapping(value = ["/update"])
    fun update(@RequestBody request: SUpdateRequest<Markers>): SBaseResponse {
        return MarkersService.updateList(request)
    } // Function update()

    /**
     * 查询注释说明信息
     *
     * @param   request        查询条件
     * @return                 查询结果
     */
    @ApiOperation(value = "查询注释说明信息", notes = "")
    @PostMapping(value = ["/query"])
    fun query(@RequestBody request: SQueryRequest): SQueryResponse<Markers> {
        return MarkersService.pageQuery(request)
    } // Function query()

} // Class NodeController