/*
 * ********************************************************************************************************************
 *
 *                     :*$@@%$*:                         ;:                ;;    ;;
 *                   :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                  :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                  =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                  =@*                                  %!              @ $= % %@=   =%@!      %=
 *             *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *           %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *         ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *         $@*   ;@@@%=!:                *@*
 *         =@$    ;;;!=%@@@@=!           =@!
 *          %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *           ;%@@$=$@@%*       *@@@$=%@@%;
 *              ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

package com.persagy.server.controller.task

import com.persagy.base.extensions.toJson
import com.persagy.database.SFilter
import com.persagy.database.functions.SLength
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.datacenter.models.entities.task.*
import com.persagy.server.datacenter.models.requests.ModelScanSQueryRequest
import com.persagy.server.services.task.ModelScanTaskQueryService
import com.persagy.server.services.task.ModelScanTaskService
import com.persagy.server.services.task.ScanTaskBaseService
import com.persagy.service.SObjectService
import com.persagy.service.SPageContext
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController


/**
 * 模型任务接口
 *
 * @author  邓婷婷
 */
@Api(tags = ["002、任务-模型任务接口"])
@RestController
@RequestMapping("/task/model")
open class ModelScanTaskController {

    companion object {
        // 日志
        private val logger = LoggerFactory.getLogger(ModelScanTaskController::class.java)
    } // Companion object

    /**
     * 根据条件查询模型任务
     *
     * @author 邓婷婷
     */
    @ApiOperation(value = "查询模型任务", notes = "级联查询对象：项目（project）、建筑（building）、楼层（floor）、方案（scanScheme）、设备分类（equipCategory）、部件（component）;" +
            "查询条件：任务类型（TaskSource--int）、任务执行情况（TaskState--int）、模型文件id（FileId）、设备类型（Category）")
    @PostMapping(value = ["/page-query"])
    fun pageQuery(@RequestBody request: SQueryRequest): SQueryResponse<ModelScanTaskQuery> {
        val equipScanTaskQueryService = SObjectService(SMybatisDao(ModelScanTaskQuery::class.java))
        val withFilterList = ArrayList<SFilter>()
        withFilterList.add(SFilter.eq("projectId", SPageContext.getHeader("ProjectId").toString()))
        withFilterList.add(SFilter.lt(SLength("category"), 6))
        return ModelScanTaskQueryService.pageQuerys(request);
    } // Function pageQuery()

    /**
     * 根据条件查询模型任务
     *
     * @author 邓婷婷
     */
    @ApiOperation(value = "查询模型任务，包含部件", notes = "级联查询对象：项目（project）、建筑（building）、楼层（floor）、方案（scanScheme）、设备分类（equipCategory）、部件（component）;" +
            "查询条件：任务类型（TaskSource--int）、任务执行情况（TaskState--int）、模型文件id（FileId）、设备类型（Category）")
    @PostMapping(value = ["/page-query-com"])
    fun pageQueryCom(@RequestBody request: SQueryRequest): SQueryResponse<ModelScanTaskQuery> {
        logger.debug("modelScanTaskQuery =${request.toJson()}")
        val equipScanTaskQueryService = SObjectService(SMybatisDao(ModelScanTaskQuery::class.java))
        val withFilterList = ArrayList<SFilter>()
        withFilterList.add(SFilter.eq("projectId", SPageContext.getHeader("ProjectId").toString()))
//        withFilterList.add(SFilter.lt(SLength("category"), 6))
        return ModelScanTaskQueryService.pageQuery(request,withFilterList);
    } // Function pageQuery()

    /**
     * 创建模型任务
     *
     * @param   request        模型任务对象列表
     * @return                      创建结果信息
     * @author  邓婷婷
     */
    @ApiOperation(value = "创建模型任务", notes = "所有属性名要以查询返回结果为准  例如：任务id应用TaskId；当任务为未找到任务时重新生成任务，需要将TaskState=-1带入;")
    @PostMapping(value = ["/create"])
    fun create(@RequestBody request: SCreateRequest<ModelScanTask>): SCreateResponse<ModelScanTask> {
        logger.debug("equip =${request.toJson()}")
        return ModelScanTaskService.createList(ModelScanTaskService.createBefore(request))
    } // Function create()

    /**
     * 更新模型任务
     *
     * @param   request      模型任务对象列表
     * @return              结果信息
     * @author  邓婷婷
     */
    @ApiOperation(value = "更新模型任务", notes = "所有属性名要以查询返回结果为准  例如：任务id应用TaskId；")
    @PostMapping(value = ["/update"])
    fun update(@RequestBody request: SUpdateRequest<ModelScanTask>): SBaseResponse {
        return ModelScanTaskService.updateList(request)
    } // Function update()


    /**
     * 根据id删除模型任务
     *
     * @param   idList      id数组
     * @return              删除的结果信息
     *
     * @author  邓婷婷
     */
    @ApiOperation(value = "根据id删除模型任务", notes = "所有属性名要以查询返回结果为准  例如：任务id应用TaskId；")
    @PostMapping(value = ["/delete"])
    fun delete(@RequestBody idList: ArrayList<ModelScanTask>): SBaseResponse {
        return ModelScanTaskService.deleteByKeysList(idList)
    } // Function delete()

    /**
     * 查询设备分类
     */
    @ApiOperation(value = "查询设备分类",notes = "")
    @PostMapping(value = ["/model-category-query"])
    fun modelCategoryQuery(): SQueryResponse<EquipCategoryDic>{
        return ScanTaskBaseService.equipCategoryQuery("model")
    } // Function pageQuery()

    /**
     * 查询模型文件夹和文件
     */
    @ApiOperation(value = "查询模型文件夹和文件",notes = "")
    @PostMapping(value = ["/model-file-query"])
    fun modelFileQuery(): SQueryResponse<ModelFolder>{
        return ModelScanTaskService.modelFileQuery()
    } // Function ModelFileQuery()

    /**
     * 查询建筑和楼层
     */
    @ApiOperation(value = "查询建筑和楼层",notes = "")
    @PostMapping(value = ["/model-building-query"])
    fun buildingQuery(): SQueryResponse<BuildingDic>{
        return ScanTaskBaseService.buildingQuery("model")
    } // Function BuildingQuery()

    /**
     * 查询根据模型空间id查询设备信息
     */
    @ApiOperation(value = "查询根据模型空间id查询设备信息",notes = "listId 模型id")
    @PostMapping(value = ["/equip-query"])
    fun equipQuery(@RequestBody request: ModelScanSQueryRequest): SQueryResponse<EquipmentTaskTwo>{
        return ModelScanTaskService.equipQuery(request)
    } // Function equipQuery()

    /**
     * 查询设备任务下的部件类型及数量
     */
    @ApiOperation(value = "查询设备任务下的部件类型及数量",notes = " TaskId、EquipId 必填")
    @PostMapping(value = ["/category-count"])
    fun categoryCount(@RequestBody equipScanTask: ModelScanTask): SQueryResponse<CategoryStatistics>{
        return ModelScanTaskService.categoryCounts(equipScanTask)
    } // Fun

} // Class ModelScanTaskController